@@ -13,9 +13,9 @@ class DingDingOptionsForm(forms.Form):
         max_length=255,
         help_text='DingTalk robot access_token',
     )
-    select = forms.TypedChoiceField(
-        label='携带字段',
-        coerce=lambda x: x == '1',
-        choices=CHOICES,
-        widget=forms.CheckboxSelectMultiple()
-    )
+    # select = forms.TypedChoiceField(
+    #     label='携带字段',
+    #     coerce=lambda x: x == '1',
+    #     choices=CHOICES,
+    #     widget=forms.CheckboxSelectMultiple()
+    # )
